@@ -74,8 +74,8 @@ class SignEncryptWizard : public Wizard
 {
     Q_OBJECT
 public:
-    explicit SignEncryptWizard(QWidget *parent = nullptr, Qt::WindowFlags f = 0);
-    virtual ~SignEncryptWizard();
+    explicit SignEncryptWizard(QWidget *parent = nullptr, Qt::WindowFlags f = {});
+    ~SignEncryptWizard() override;
 
     enum Page {
         ResolveSignerPage = 0,
